get_p_macroareas: Macroareas' probability of usage

Description Usage Arguments Value Examples

View source: R/get_p_macroareas.R

Description

this function comput the probabilities for macroareas to use a "next" organ based on the portion of organs offered and the probability to accept them from the centers. The probability that the organ will be lost is also returned.

Usage

1

Arguments

state

an object of class state.

Value

a data.frame with two columns, the first reporting the macroareas' name or "lost", and the second reporting the probability that a "next" organ will be effectively used by that macroarea (or will be lost).

Examples

1
2
3
4
## Not run: 
  get_p_macroareas(italy)

## End(Not run)

UBESP-DCTV/clumpr documentation built on July 3, 2021, 11:23 p.m.