Description Usage Arguments Value Examples
View source: R/get_p_macroareas.R
this function comput the probabilities for macroareas to use a "next" organ based on the portion of organs offered and the probability to accept them from the centers. The probability that the organ will be lost is also returned.
1 |
state |
an object of class |
a data.frame with two columns, the first reporting the
macroareas' name or "lost", and the second reporting the probability
that a "next" organ will be effectively used by that macroarea (or
will be lost).
1 2 3 4 | ## Not run:
get_p_macroareas(italy)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.